package Plugins::digitalSTROM::Settings;


# Squeezebox Server digitalSTROM Plugin Copyright 2010 Manfred Stock.
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 3.

use strict;
use base qw(Slim::Web::Settings);
use Slim::Utils::Prefs;
use Slim::Utils::Log;
use Slim::Web::HTTP::CSRF;

my $log = Slim::Utils::Log->addLogCategory({
	'category'     => 'plugin.digitalSTROM',
	'defaultLevel' => 'INFO',
#	'defaultLevel' => 'DEBUG',
	'description'  => 'digitalSTROM Settings',
});

my $prefs = preferences('plugin.digitalstrom');

=head1 NAME

Plugins::digitalSTROM::Settings - Perl module to handle plugin settings.

=head1 SYNOPSIS

	use Plugins::digitalSTROM::Settings;

	... code example

=head1 DESCRIPTION

Plugins::digitalSTROM::Settings handles the plugin settings for the digitalSTROM
Squeezebox Server plugin.

=head1 METHODS

=head2 name

Getter for the name of the plugin.

=head3 Result

The plugin name.

=cut

sub name {
	return 'PLUGIN_DIGITALSTROM';
}


=head2 page

Getter for the relative settings page URL.

=head3 Result

The relative settings page URL.

=cut

sub page {
	return 'plugins/digitalSTROM/settings/basic.html';
}


=head2 handler

Handler to process web page input.

=head3 Result

Some result.

=cut

sub handler {
	my ($class, $client, $params) = @_;

	# Store DSS URL
	if ($params->{saveSettings} && defined $params->{dssurl}) {
		my $dssurl = $params->{dssurl};
		$prefs->set('dssurl', $dssurl);
	}

	# Add URL to webpage
	$params->{prefs}->{dssurl} = $prefs->get('dssurl');

	return $class->SUPER::handler($client, $params);
}

1;

=head1 COPYRIGHT AND LICENSE

Copyright 2010-2011 Manfred Stock, futureLAB AG.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
